@@ -26,6 +26,8 @@ class TrailblazerAnalysis(BaseModel):
     user_id: Optional[int]
     progress: Optional[float] = 0.0
     data_analysis: Optional[str]
+    ticket: Optional[str]
+    uploaded_at: Optional[str]
 
     @validator("case_id")
     def inherit_family_value(cls, value: str, values: dict) -> str:
