@@ -1,26 +1,31 @@
 """Code for validating an upload via CLI"""
+from typing import List, Optional
 
 import click
 from cg.apps.coverage import ChanjoAPI
+from cg.models.cg_config import CGConfig
+from cg.store import Store
 
 from .utils import suggest_cases_to_upload
 
 
 @click.command()
 @click.argument("family_id", required=False)
-@click.pass_context
-def validate(context, family_id):
+@click.pass_obj
+def validate(context: CGConfig, family_id: Optional[str]):
     """Validate a family of samples."""
 
+    status_db: Store = context.status_db
+    chanjo_api: ChanjoAPI = context.chanjo_api
+
     click.echo(click.style("----------------- VALIDATE --------------------"))
 
     if not family_id:
-        suggest_cases_to_upload(context)
-        context.abort()
+        suggest_cases_to_upload(status_db=status_db)
+        raise click.Abort
 
-    case_obj = context.obj["status_db"].family(family_id)
-    chanjo_api = ChanjoAPI(context.obj)
-    chanjo_samples = []
+    case_obj = status_db.get_case_by_internal_id(internal_id=family_id)
+    chanjo_samples: List[dict] = []
     for link_obj in case_obj.links:
         sample_id = link_obj.sample.internal_id
         chanjo_sample = chanjo_api.sample(sample_id)
@@ -40,4 +45,4 @@ def validate(context, family_id):
             mean_coverage = coverage_results[sample_id]["mean_coverage"]
             click.echo(f"{sample_id}: {mean_coverage:.2f}X - {completeness:.2f}%")
         else:
-            click.echo(f"{sample_id}: sample not found in chanjo", color="yellow")
+            click.echo(click.style(f"{sample_id}: sample not found in chanjo", fg="yellow"))
