@@ -20,10 +20,13 @@ LIMS_PASSWORD = os.environ["LIMS_PASSWORD"]
 
 OSTICKET_API_KEY = os.environ.get("OSTICKET_API_KEY")
 OSTICKET_DOMAIN = os.environ.get("OSTICKET_DOMAIN")
+SUPPORT_SYSTEM_EMAIL = os.environ.get("SUPPORT_SYSTEM_EMAIL")
+EMAIL_URI = os.environ.get("EMAIL_URI")
+
 
 # oauth
 GOOGLE_OAUTH_CLIENT_ID = os.environ["GOOGLE_OAUTH_CLIENT_ID"]
 GOOGLE_OAUTH_CLIENT_SECRET = os.environ["GOOGLE_OAUTH_CLIENT_SECRET"]
 
 # invoice
-TOTAL_PRICE_TRESHOLD = 750000
+TOTAL_PRICE_THRESHOLD = 750000
