@@ -1,14 +1,9 @@
 from flask_admin import Admin
-from flask_alchy import Alchy
 from flask_cors import CORS
-
+from flask_wtf.csrf import CSRFProtect
 from cg.apps.lims import LimsAPI
 from cg.apps.osticket import OsTicket
-from cg.store import models, api
-
-
-class CgAlchy(Alchy, api.CoreHandler):
-    pass
+from cg.store.api.core import Store
 
 
 class FlaskLims(LimsAPI):
@@ -27,8 +22,20 @@ class FlaskLims(LimsAPI):
         super(FlaskLims, self).__init__(config)
 
 
+class FlaskStore(Store):
+    def __init__(self, app=None):
+        if app:
+            self.init_app(app)
+
+    def init_app(self, app):
+        uri = app.config["SQLALCHEMY_DATABASE_URI"]
+        super(FlaskStore, self).__init__(uri)
+
+
 cors = CORS(resources={r"/api/*": {"origins": "*"}}, supports_credentials=True)
-db = CgAlchy(Model=models.Model)
+csrf = CSRFProtect()
+db = FlaskStore()
+
 admin = Admin(name="Clinical Genomics")
 lims = FlaskLims()
 osticket = OsTicket()
