@@ -1,22 +1,35 @@
-# -*- coding: utf-8 -*-
 import datetime as dt
-from typing import List
+import re
+from typing import List, Optional, Set, Dict
+
+from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy import Column, ForeignKey, Table, UniqueConstraint, orm, types
+from sqlalchemy.util import deprecated
+from sqlalchemy.orm.attributes import InstrumentedAttribute
 
-import alchy
 from cg.constants import (
     CASE_ACTIONS,
     FLOWCELL_STATUS,
     PREP_CATEGORIES,
-    PRIORITY_MAP,
-    REV_PRIORITY_MAP,
+    Priority,
     SEX_OPTIONS,
     STATUS_OPTIONS,
     DataDelivery,
     Pipeline,
 )
-from sqlalchemy import Column, ForeignKey, Table, UniqueConstraint, orm, types
 
-Model = alchy.make_declarative_base(Base=alchy.ModelBase)
+from cg.constants.constants import CONTROL_OPTIONS, PrepCategory
+
+Model = declarative_base()
+
+
+def to_dict(model_instance):
+    if hasattr(model_instance, "__table__"):
+        return {
+            column.name: getattr(model_instance, column.name)
+            for column in model_instance.__table__.columns
+            if not isinstance(getattr(model_instance, column.name), InstrumentedAttribute)
+        }
 
 
 flowcell_sample = Table(
@@ -27,29 +40,56 @@ flowcell_sample = Table(
     UniqueConstraint("flowcell_id", "sample_id", name="_flowcell_sample_uc"),
 )
 
+customer_user = Table(
+    "customer_user",
+    Model.metadata,
+    Column("customer_id", types.Integer, ForeignKey("customer.id"), nullable=False),
+    Column("user_id", types.Integer, ForeignKey("user.id"), nullable=False),
+    UniqueConstraint("customer_id", "user_id", name="_customer_user_uc"),
+)
+
+customer_collaboration = Table(
+    "customer_collaboration",
+    Model.metadata,
+    Column("customer_id", types.Integer, ForeignKey("customer.id"), nullable=False),
+    Column("collaboration_id", types.Integer, ForeignKey("collaboration.id"), nullable=False),
+    UniqueConstraint("customer_id", "collaboration_id", name="_customer_collaboration_uc"),
+)
+
 
 class PriorityMixin:
     @property
-    def priority_human(self):
+    def priority_human(self) -> str:
         """Humanized priority for sample."""
-        return REV_PRIORITY_MAP[self.priority]
+        return self.priority.name
 
     @priority_human.setter
-    def priority_human(self, priority_str: str):
-        self.priority = PRIORITY_MAP.get(priority_str)
+    def priority_human(self, priority: str) -> None:
+        self.priority: Priority = Priority[priority]
+
+    @property
+    def priority_int(self) -> int:
+        """Priority as integer for sample."""
+        return self.priority.value
+
+    @priority_int.setter
+    def priority_int(self, priority_int: int) -> None:
+        self.priority: Priority = Priority(priority_int)
 
     @property
     def high_priority(self):
         """Has high priority?"""
-        return self.priority > 1
+        return self.priority_int > 1
 
     @property
     def low_priority(self):
         """Has low priority?"""
-        return self.priority < 1
+        return self.priority_int < 1
 
 
 class Application(Model):
+    __tablename__ = "application"
+
     id = Column(types.Integer, primary_key=True)
     tag = Column(types.String(32), unique=True, nullable=False)
     prep_category = Column(types.Enum(*PREP_CATEGORIES), nullable=False)
@@ -60,7 +100,7 @@ class Application(Model):
     turnaround_time = Column(types.Integer)
     minimum_order = Column(types.Integer, default=1)
     sequencing_depth = Column(types.Integer)
-    min_sequencing_depth = Column(types.Integer)
+    min_sequencing_depth = Column(types.Integer, default=0, nullable=False)
     target_reads = Column(types.BigInteger, default=0)
     percent_reads_guaranteed = Column(types.Integer, nullable=False)
     sample_amount = Column(types.Integer)
@@ -88,18 +128,25 @@ class Application(Model):
 
     @property
     def expected_reads(self):
-        return self.target_reads * 0.75
+        return self.target_reads * self.percent_reads_guaranteed / 100
 
     @property
     def analysis_type(self):
-
-        if self.prep_category == "wts":
+        if self.prep_category == PrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING.value:
             return self.prep_category
 
-        return "wgs" if self.prep_category == "wgs" else "wes"
+        return (
+            PrepCategory.WHOLE_GENOME_SEQUENCING.value
+            if self.prep_category == PrepCategory.WHOLE_GENOME_SEQUENCING.value
+            else PrepCategory.WHOLE_EXOME_SEQUENCING.value
+        )
+
+    def to_dict(self):
+        return to_dict(model_instance=self)
 
 
 class ApplicationVersion(Model):
+    __tablename__ = "application_version"
     __table_args__ = (UniqueConstraint("application_id", "version", name="_app_version_uc"),)
 
     id = Column(types.Integer, primary_key=True)
@@ -110,6 +157,7 @@ class ApplicationVersion(Model):
     price_priority = Column(types.Integer)
     price_express = Column(types.Integer)
     price_research = Column(types.Integer)
+    price_clinical_trials = Column(types.Integer)
     comment = Column(types.Text)
 
     created_at = Column(types.DateTime, default=dt.datetime.now)
@@ -121,13 +169,15 @@ class ApplicationVersion(Model):
 
     def to_dict(self, application: bool = True):
         """Represent as dictionary"""
-        data = super(ApplicationVersion, self).to_dict()
+        data = to_dict(model_instance=self)
         if application:
             data["application"] = self.application.to_dict()
         return data
 
 
 class Analysis(Model):
+    __tablename__ = "analysis"
+
     id = Column(types.Integer, primary_key=True)
     pipeline = Column(types.Enum(*list(Pipeline)))
     pipeline_version = Column(types.String(32))
@@ -142,21 +192,23 @@ class Analysis(Model):
 
     created_at = Column(types.DateTime, default=dt.datetime.now, nullable=False)
     family_id = Column(ForeignKey("family.id", ondelete="CASCADE"))
+    uploaded_to_vogue_at = Column(types.DateTime, nullable=True)
 
     def __str__(self):
         return f"{self.family.internal_id} | {self.completed_at.date()}"
 
     def to_dict(self, family: bool = True):
         """Represent as dictionary"""
-        data = super(Analysis, self).to_dict()
+        data = to_dict(model_instance=self)
         if family:
             data["family"] = self.family.to_dict()
         return data
 
 
 class Bed(Model):
-    """Model for bed target captures """
+    """Model for bed target captures"""
 
+    __tablename__ = "bed"
     id = Column(types.Integer, primary_key=True)
     name = Column(types.String(32), unique=True, nullable=False)
     comment = Column(types.Text)
@@ -169,10 +221,14 @@ class Bed(Model):
     def __str__(self) -> str:
         return self.name
 
+    def to_dict(self):
+        return to_dict(model_instance=self)
+
 
 class BedVersion(Model):
-    """Model for bed target captures versions """
+    """Model for bed target captures versions"""
 
+    __tablename__ = "bed_version"
     __table_args__ = (UniqueConstraint("bed_id", "version", name="_app_version_uc"),)
 
     id = Column(types.Integer, primary_key=True)
@@ -193,55 +249,83 @@ class BedVersion(Model):
 
     def to_dict(self, bed: bool = True):
         """Represent as dictionary"""
-        data = super(BedVersion, self).to_dict()
+        data = to_dict(model_instance=self)
         if bed:
             data["bed"] = self.bed.to_dict()
         return data
 
 
 class Customer(Model):
-    id = Column(types.Integer, primary_key=True)
-    internal_id = Column(types.String(32), unique=True, nullable=False)
-    name = Column(types.String(128), nullable=False)
-    priority = Column(types.Enum("diagnostic", "research"))
-    scout_access = Column(types.Boolean, nullable=False, default=False)
-    loqus_upload = Column(types.Boolean, nullable=False, default=False)
-    return_samples = Column(types.Boolean, nullable=False, default=False)
-
+    __tablename__ = "customer"
     agreement_date = Column(types.DateTime)
     agreement_registration = Column(types.String(32))
-    project_account_ki = Column(types.String(32))
-    project_account_kth = Column(types.String(32))
-    organisation_number = Column(types.String(32))
+    comment = Column(types.Text)
+    id = Column(types.Integer, primary_key=True)
+    internal_id = Column(types.String(32), unique=True, nullable=False)
     invoice_address = Column(types.Text, nullable=False)
     invoice_reference = Column(types.String(32), nullable=False)
+    is_trusted = Column(types.Boolean, nullable=False, default=False)
+    loqus_upload = Column(types.Boolean, nullable=False, default=False)
+    name = Column(types.String(128), nullable=False)
+    organisation_number = Column(types.String(32))
+    priority = Column(types.Enum("diagnostic", "research"))
+    project_account_ki = Column(types.String(32))
+    project_account_kth = Column(types.String(32))
+    return_samples = Column(types.Boolean, nullable=False, default=False)
+    scout_access = Column(types.Boolean, nullable=False, default=False)
     uppmax_account = Column(types.String(32))
-    comment = Column(types.Text)
 
-    primary_contact_id = Column(ForeignKey("user.id"))
-    primary_contact = orm.relationship("User", foreign_keys=[primary_contact_id])
+    collaborations = orm.relationship("Collaboration", secondary=customer_collaboration)
     delivery_contact_id = Column(ForeignKey("user.id"))
     delivery_contact = orm.relationship("User", foreign_keys=[delivery_contact_id])
     invoice_contact_id = Column(ForeignKey("user.id"))
     invoice_contact = orm.relationship("User", foreign_keys=[invoice_contact_id])
-    customer_group_id = Column(ForeignKey("customer_group.id"), nullable=False)
+    primary_contact_id = Column(ForeignKey("user.id"))
+    primary_contact = orm.relationship("User", foreign_keys=[primary_contact_id])
 
     def __str__(self) -> str:
         return f"{self.internal_id} ({self.name})"
 
+    @property
+    def collaborators(self) -> Set["Customer"]:
+        """All customers that the current customer collaborates with (including itself)"""
+        customers = {
+            customer
+            for collaboration in self.collaborations
+            for customer in collaboration.customers
+        }
+        customers.add(self)
+        return customers
 
-class CustomerGroup(Model):
+    def to_dict(self):
+        return to_dict(model_instance=self)
+
+
+class Collaboration(Model):
+    __tablename__ = "collaboration"
     id = Column(types.Integer, primary_key=True)
     internal_id = Column(types.String(32), unique=True, nullable=False)
     name = Column(types.String(128), nullable=False)
-
-    customers = orm.relationship(Customer, backref="customer_group", order_by="-Customer.id")
+    customers = orm.relationship(Customer, secondary=customer_collaboration)
 
     def __str__(self) -> str:
         return f"{self.internal_id} ({self.name})"
 
+    def to_dict(self):
+        """Represent as dictionary"""
+        return {
+            "customers": [customer.internal_id for customer in self.customers],
+            "id": self.id,
+            "name": self.name,
+            "internal_id": self.internal_id,
+        }
+
+    def to_dict(self):
+        return to_dict(model_instance=self)
+
 
 class Delivery(Model):
+    __tablename__ = "delivery"
     id = Column(types.Integer, primary_key=True)
     delivered_at = Column(types.DateTime)
     removed_at = Column(types.DateTime)
@@ -250,12 +334,17 @@ class Delivery(Model):
     pool_id = Column(ForeignKey("pool.id", ondelete="CASCADE"))
     comment = Column(types.Text)
 
+    def to_dict(self):
+        return to_dict(model_instance=self)
+
 
 class Family(Model, PriorityMixin):
+    __tablename__ = "family"
     __table_args__ = (UniqueConstraint("customer_id", "name", name="_customer_name_uc"),)
 
     action = Column(types.Enum(*CASE_ACTIONS))
     analyses = orm.relationship(Analysis, backref="family", order_by="-Analysis.completed_at")
+    _cohorts = Column(types.Text)
     comment = Column(types.Text)
     created_at = Column(types.DateTime, default=dt.datetime.now)
     customer_id = Column(ForeignKey("customer.id", ondelete="CASCADE"), nullable=False)
@@ -267,14 +356,107 @@ class Family(Model, PriorityMixin):
     name = Column(types.String(128), nullable=False)
     ordered_at = Column(types.DateTime, default=dt.datetime.now)
     _panels = Column(types.Text)
-    priority = Column(types.Integer, default=1, nullable=False)
+
+    priority = Column(types.Enum(Priority), default=Priority.standard, nullable=False)
+    synopsis = Column(types.Text)
+    tickets = Column(types.VARCHAR)
+
+    @property
+    def cohorts(self) -> List[str]:
+        """Return a list of cohorts."""
+        return self._cohorts.split(",") if self._cohorts else []
+
+    @cohorts.setter
+    def cohorts(self, cohort_list: List[str]):
+        self._cohorts = ",".join(cohort_list) if cohort_list else None
+
+    @property
+    def panels(self) -> List[str]:
+        """Return a list of panels."""
+        return self._panels.split(",") if self._panels else []
+
+    @panels.setter
+    def panels(self, panel_list: List[str]):
+        self._panels = ",".join(panel_list) if panel_list else None
+
+    @property
+    def latest_ticket(self) -> Optional[str]:
+        """Returns the last ticket the family was ordered in"""
+        return self.tickets.split(sep=",")[-1] if self.tickets else None
+
+    @property
+    def latest_analyzed(self) -> Optional[dt.datetime]:
+        return self.analyses[0].completed_at if self.analyses else None
+
+    @property
+    def latest_sequenced(self) -> Optional[dt.datetime]:
+        sequenced_dates = []
+        for link in self.links:
+            if link.sample.application_version.application.is_external:
+                sequenced_dates.append(link.sample.ordered_at)
+            elif link.sample.sequenced_at:
+                sequenced_dates.append(link.sample.sequenced_at)
+        return max(sequenced_dates, default=None)
+
+    @property
+    def all_samples_pass_qc(self) -> bool:
+        pass_qc = []
+        for link in self.links:
+            if link.sample.application_version.application.is_external or link.sample.sequencing_qc:
+                pass_qc.append(True)
+            else:
+                pass_qc.append(False)
+        return all(pass_qc)
 
     def __str__(self) -> str:
         return f"{self.internal_id} ({self.name})"
 
+    @property
+    def samples(self) -> List["Sample"]:
+        """Return case samples."""
+        return self._get_samples
+
+    @property
+    def _get_samples(self) -> List["Sample"]:
+        """Extract samples from a case."""
+        return [link.sample for link in self.links]
+
+    @property
+    def tumour_samples(self) -> List["Sample"]:
+        """Return tumour samples."""
+        return self._get_tumour_samples
+
+    @property
+    def _get_tumour_samples(self) -> List["Sample"]:
+        """Extract tumour samples."""
+        return [link.sample for link in self.links if link.sample.is_tumour]
+
+    @property
+    def loqusdb_uploaded_samples(self) -> List["Sample"]:
+        """Return uploaded samples to Loqusdb."""
+        return self._get_loqusdb_uploaded_samples
+
+    @property
+    def _get_loqusdb_uploaded_samples(self) -> List["Sample"]:
+        """Extract samples uploaded to Loqusdb."""
+        return [link.sample for link in self.links if link.sample.loqusdb_id]
+
+    def get_delivery_arguments(self) -> Set[str]:
+        """Translates the case data_delivery field to pipeline specific arguments."""
+        delivery_arguments: Set[str] = set()
+        requested_deliveries: List[str] = re.split("[-_]", self.data_delivery)
+        delivery_per_pipeline_map: Dict[str, str] = {
+            DataDelivery.FASTQ: Pipeline.FASTQ,
+            DataDelivery.ANALYSIS_FILES: self.data_analysis,
+        }
+        for data_delivery, pipeline in delivery_per_pipeline_map.items():
+            if data_delivery in requested_deliveries:
+                delivery_arguments.add(pipeline)
+        return delivery_arguments
+
     def to_dict(self, links: bool = False, analyses: bool = False) -> dict:
-        """Represent as dictionary"""
-        data = super(Family, self).to_dict()
+        """Represent as dictionary."""
+        data = to_dict(model_instance=self)
         data["panels"] = self.panels
         data["priority"] = self.priority_human
         data["customer"] = self.customer.to_dict()
@@ -286,18 +468,9 @@ class Family(Model, PriorityMixin):
             ]
         return data
 
-    @property
-    def panels(self) -> List[str]:
-        """Return a list of panels."""
-        panel_list = self._panels.split(",") if self._panels else []
-        return panel_list
-
-    @panels.setter
-    def panels(self, panel_list: List[str]):
-        self._panels = ",".join(panel_list) if panel_list else None
-
 
 class FamilySample(Model):
+    __tablename__ = "family_sample"
     __table_args__ = (UniqueConstraint("family_id", "sample_id", name="_family_sample_uc"),)
 
     id = Column(types.Integer, primary_key=True)
@@ -318,7 +491,7 @@ class FamilySample(Model):
 
     def to_dict(self, parents: bool = False, samples: bool = False, family: bool = False) -> dict:
         """Represent as dictionary"""
-        data = super(FamilySample, self).to_dict()
+        data = to_dict(model_instance=self)
         if samples:
             data["sample"] = self.sample.to_dict()
             data["mother"] = self.mother.to_dict() if self.mother else None
@@ -335,6 +508,7 @@ class FamilySample(Model):
 
 
 class Flowcell(Model):
+    __tablename__ = "flowcell"
     id = Column(types.Integer, primary_key=True)
     name = Column(types.String(32), unique=True, nullable=False)
     sequencer_type = Column(types.Enum("hiseqga", "hiseqx", "novaseq"))
@@ -345,19 +519,21 @@ class Flowcell(Model):
     updated_at = Column(types.DateTime, onupdate=dt.datetime.now)
 
     samples = orm.relationship("Sample", secondary=flowcell_sample, backref="flowcells")
+    sequencing_metrics = orm.relationship("SampleLaneSequencingMetrics", back_populates="flowcell")
 
     def __str__(self):
         return self.name
 
     def to_dict(self, samples: bool = False):
         """Represent as dictionary"""
-        data = super(Flowcell, self).to_dict()
+        data = to_dict(model_instance=Flowcell)
         if samples:
             data["samples"] = [sample.to_dict() for sample in self.samples]
         return data
 
 
 class Organism(Model):
+    __tablename__ = "organism"
     id = Column(types.Integer, primary_key=True)
     internal_id = Column(types.String(32), nullable=False, unique=True)
     name = Column(types.String(255), nullable=False, unique=True)
@@ -372,12 +548,11 @@ class Organism(Model):
 
     def to_dict(self) -> dict:
         """Represent as dictionary"""
-        data = super(Organism, self).to_dict()
-        return data
+        return to_dict(model_instance=self)
 
 
 class Panel(Model):
-
+    __tablename__ = "panel"
     abbrev = Column(types.String(32), unique=True)
     current_version = Column(types.Float, nullable=False)
     customer_id = Column(ForeignKey("customer.id", ondelete="CASCADE"), nullable=False)
@@ -390,8 +565,12 @@ class Panel(Model):
     def __str__(self):
         return f"{self.abbrev} ({self.current_version})"
 
+    def to_dict(self):
+        return to_dict(model_instance=self)
+
 
 class Pool(Model):
+    __tablename__ = "pool"
     __table_args__ = (UniqueConstraint("order", "name", name="_order_name_uc"),)
 
     application_version_id = Column(ForeignKey("application_version.id"), nullable=False)
@@ -411,17 +590,22 @@ class Pool(Model):
     order = Column(types.String(64), nullable=False)
     ordered_at = Column(types.DateTime, nullable=False)
     received_at = Column(types.DateTime)
-    ticket_number = Column(types.Integer)
+    ticket = Column(types.String(32))
+
+    def to_dict(self):
+        return to_dict(model_instance=self)
 
 
 class Sample(Model, PriorityMixin):
-
+    __tablename__ = "sample"
+    age_at_sampling = Column(types.FLOAT)
     application_version_id = Column(ForeignKey("application_version.id"), nullable=False)
     application_version = orm.relationship(
         ApplicationVersion, foreign_keys=[application_version_id]
     )
     capture_kit = Column(types.String(64))
     comment = Column(types.Text)
+    control = Column(types.Enum(*CONTROL_OPTIONS))
     created_at = Column(types.DateTime, default=dt.datetime.now)
     customer_id = Column(ForeignKey("customer.id", ondelete="CASCADE"), nullable=False)
     customer = orm.relationship("Customer", foreign_keys=[customer_id])
@@ -433,7 +617,7 @@ class Sample(Model, PriorityMixin):
     internal_id = Column(types.String(32), nullable=False, unique=True)
     invoice_id = Column(ForeignKey("invoice.id"))
     invoiced_at = Column(types.DateTime)  # DEPRECATED
-    is_external = Column(types.Boolean, default=False)  # DEPRECATED
+    _is_external = Column("is_external", types.Boolean)  # DEPRECATED
     is_tumour = Column(types.Boolean, default=False)
     loqusdb_id = Column(types.String(64))
     name = Column(types.String(128), nullable=False)
@@ -442,37 +626,86 @@ class Sample(Model, PriorityMixin):
     ordered_at = Column(types.DateTime, nullable=False)
     organism_id = Column(ForeignKey("organism.id"))
     organism = orm.relationship("Organism", foreign_keys=[organism_id])
+    original_ticket = Column(types.String(32))
+    _phenotype_groups = Column(types.Text)
+    _phenotype_terms = Column(types.Text)
     prepared_at = Column(types.DateTime)
-    priority = Column(types.Integer, default=1, nullable=False)
+
+    priority = Column(types.Enum(Priority), default=Priority.standard, nullable=False)
     reads = Column(types.BigInteger, default=0)
     received_at = Column(types.DateTime)
     reference_genome = Column(types.String(255))
     sequence_start = Column(types.DateTime)
     sequenced_at = Column(types.DateTime)
     sex = Column(types.Enum(*SEX_OPTIONS), nullable=False)
-    ticket_number = Column(types.Integer)
-    time_point = Column(types.Integer)
+    subject_id = Column(types.String(128))
+
+    sequencing_metrics = orm.relationship("SampleLaneSequencingMetrics", back_populates="sample")
 
     def __str__(self) -> str:
         return f"{self.internal_id} ({self.name})"
 
+    @property
+    @deprecated(
+        version="1.4.0",
+        message="This field is deprecated, use sample.application_version.application.is_external",
+    )
+    def is_external(self):
+        """Return if this is an externally sequenced sample."""
+        return self._is_external
+
+    @property
+    def sequencing_qc(self) -> bool:
+        """Return sequencing qc passed or failed."""
+        application = self.application_version.application
+        # Express priority needs to be analyzed at a lower threshold for primary analysis
+        if self.priority == Priority.express:
+            one_half_of_target_reads = application.target_reads / 2
+            return self.reads >= one_half_of_target_reads
+        if self.application_version.application.prep_category == PrepCategory.READY_MADE_LIBRARY:
+            return bool(self.reads)
+        return self.reads > application.expected_reads
+
+    @property
+    def phenotype_groups(self) -> List[str]:
+        """Return a list of phenotype_groups."""
+        return self._phenotype_groups.split(",") if self._phenotype_groups else []
+
+    @phenotype_groups.setter
+    def phenotype_groups(self, phenotype_term_list: List[str]):
+        self._phenotype_groups = ",".join(phenotype_term_list) if phenotype_term_list else None
+
+    @property
+    def phenotype_terms(self) -> List[str]:
+        """Return a list of phenotype_terms."""
+        return self._phenotype_terms.split(",") if self._phenotype_terms else []
+
+    @phenotype_terms.setter
+    def phenotype_terms(self, phenotype_term_list: List[str]):
+        self._phenotype_terms = ",".join(phenotype_term_list) if phenotype_term_list else None
+
+    @property
+    def prep_category(self) -> str:
+        """Return the preparation category of the sample."""
+        return self.application_version.application.prep_category
+
     @property
     def state(self) -> str:
         """Get the current sample state."""
         if self.delivered_at:
             return f"Delivered {self.delivered_at.date()}"
-        elif self.sequenced_at:
+        if self.sequenced_at:
             return f"Sequenced {self.sequenced_at.date()}"
-        elif self.sequence_start:
+        if self.sequence_start:
             return f"Sequencing {self.sequence_start.date()}"
-        elif self.received_at:
+        if self.received_at:
             return f"Received {self.received_at.date()}"
-        else:
-            return f"Ordered {self.ordered_at.date()}"
+
+        return f"Ordered {self.ordered_at.date()}"
 
     def to_dict(self, links: bool = False, flowcells: bool = False) -> dict:
         """Represent as dictionary"""
-        data = super(Sample, self).to_dict()
+        data = to_dict(model_instance=self)
         data["priority"] = self.priority_human
         data["customer"] = self.customer.to_dict()
         data["application_version"] = self.application_version.to_dict()
@@ -485,6 +718,7 @@ class Sample(Model, PriorityMixin):
 
 
 class Invoice(Model):
+    __tablename__ = "invoice"
     id = Column(types.Integer, primary_key=True)
     customer_id = Column(ForeignKey("customer.id"), nullable=False)
     customer = orm.relationship(Customer, foreign_keys=[customer_id])
@@ -506,26 +740,44 @@ class Invoice(Model):
 
     def to_dict(self) -> dict:
         """Represent as dictionary"""
-        data = super(Invoice, self).to_dict()
-        return data
+        return to_dict(model_instance=self)
 
 
 class User(Model):
+    __tablename__ = "user"
     id = Column(types.Integer, primary_key=True)
     name = Column(types.String(128), nullable=False)
     email = Column(types.String(128), unique=True, nullable=False)
     is_admin = Column(types.Boolean, default=False)
+    order_portal_login = Column(types.Boolean, default=False)
 
-    customer_id = Column(
-        ForeignKey("customer.id", ondelete="CASCADE", use_alter=True), nullable=False
-    )
-    customer = orm.relationship("Customer", foreign_keys=[customer_id])
+    customers = orm.relationship("Customer", secondary=customer_user, backref="users")
 
     def to_dict(self) -> dict:
-        """Represent as dictionary"""
-        data = super(User, self).to_dict()
-        data["customer"] = self.customer.to_dict()
-        return data
+        """Represent as dictionary."""
+        dict_representation: dict = to_dict(model_instance=self)
+        dict_representation["customers"] = [customer.to_dict() for customer in self.customers]
+        return dict_representation
 
     def __str__(self) -> str:
         return self.name
+
+
+class SampleLaneSequencingMetrics(Model):
+    """Model for storing sequencing metrics per lane and sample."""
+
+    __tablename__ = "sample_lane_sequencing_metrics"
+
+    id = Column(types.Integer, primary_key=True)
+    flow_cell_name = Column(types.String(32), ForeignKey("flowcell.name"), nullable=False)
+    flow_cell_lane_number = Column(types.Integer)
+
+    sample_internal_id = Column(types.String(32), ForeignKey("sample.internal_id"), nullable=False)
+    sample_total_reads_in_lane = Column(types.BigInteger)
+    sample_base_fraction_passing_q30 = Column(types.Numeric(6, 2))
+    sample_base_mean_quality_score = Column(types.Numeric(6, 2))
+
+    created_at = Column(types.DateTime)
+
+    flowcell = orm.relationship(Flowcell, back_populates="sequencing_metrics")
+    sample = orm.relationship(Sample, back_populates="sequencing_metrics")
