@@ -1,15 +1,9 @@
 from enum import Enum, EnumMeta
 
 from flask_admin.form import Select2Field
-from wtforms import SelectMultipleField
-from wtforms.compat import text_type
 
 
 class EnumField:
-    @staticmethod
-    def get_name(enum_instance):
-        return enum_instance.name
-
     @staticmethod
     def get_value(enum_instance):
         return enum_instance.value
@@ -33,7 +27,7 @@ class EnumField:
     def coerce(data):
         if isinstance(data, Enum):
             return data.value
-        return text_type(data)
+        return str(data)
 
 
 class SelectEnumField(Select2Field, EnumField):
@@ -42,11 +36,3 @@ class SelectEnumField(Select2Field, EnumField):
     ):
         kwargs = self.apply_choices(enum_class, label_function, kwargs)
         super().__init__(*args, **kwargs)
-
-
-class SelectMultipleEnumField(SelectMultipleField, EnumField):
-    def __init__(
-        self, *args, enum_class: EnumMeta, label_function=EnumField.default_label_function, **kwargs
-    ):
-        kwargs = self.apply_choices(enum_class, label_function, kwargs)
-        super().__init__(*args, **kwargs)
