@@ -2,11 +2,13 @@
 import logging
 
 from cg.cli.workflow.microsalt.base import run
+from cg.models.cg_config import CGConfig
+from click.testing import CliRunner
 
 EXIT_SUCCESS = 0
 
 
-def test_no_arguments(cli_runner, base_context):
+def test_no_arguments(cli_runner: CliRunner, base_context: CGConfig):
     """Test command without any options"""
 
     # GIVEN
@@ -18,16 +20,14 @@ def test_no_arguments(cli_runner, base_context):
     assert result.exit_code != EXIT_SUCCESS
 
 
-def test_dry_arguments(
-    cli_runner, base_context, microbial_ticket, queries_path, fastq_path, caplog
-):
-    """Test command dry """
+def test_dry_arguments(cli_runner: CliRunner, base_context: CGConfig, ticket_id, caplog):
+    """Test command dry"""
 
     # GIVEN
     caplog.set_level(logging.INFO)
 
     # WHEN dry running without anything specified
-    result = cli_runner.invoke(run, [microbial_ticket, "-t", "-d"], obj=base_context)
+    result = cli_runner.invoke(run, [ticket_id, "-t", "-d"], obj=base_context)
 
     # THEN command should mention missing arguments
     assert result.exit_code == EXIT_SUCCESS
