@@ -4,7 +4,7 @@ import logging
 from cg.cli.workflow.mip_rna.base import link
 
 
-def test_cg_workflow_mip_rna_link(cli_runner, caplog, case_id, rna_mip_context):
+def test_cg_workflow_mip_rna_link(cli_runner, caplog, case_id, mip_rna_context):
     """Test print the MIP rna case config command to console"""
 
     caplog.set_level(logging.INFO)
@@ -12,8 +12,7 @@ def test_cg_workflow_mip_rna_link(cli_runner, caplog, case_id, rna_mip_context):
     # GIVEN a store with a RNA case with wts application
 
     # WHEN we run a case in dry run mode
-    result = cli_runner.invoke(link, ["-c", case_id], obj=rna_mip_context)
+    result = cli_runner.invoke(link, [case_id], obj=mip_rna_context)
 
     # THEN the command should be printed
     assert result.exit_code == 0
-    assert f"mip-rna link" in caplog.text
