@@ -5,7 +5,13 @@ import logging
 import tempfile
 from contextlib import contextmanager
 from pathlib import Path
-from typing import List, Set
+from typing import List, Optional, Dict, Set
+
+from cg.apps.housekeeper.hk import HousekeeperAPI
+from cg.constants import SequencingFileTag
+from cg.exc import HousekeeperBundleVersionMissingError
+
+from housekeeper.store.models import File, Version, Bundle
 
 ROOT_PATH = tempfile.TemporaryDirectory().name
 
@@ -105,14 +111,14 @@ class MockVersion:
         return f"MockVersion:id={self.id}, created_at={self.created_at}, files={self.files}"
 
 
-class EnhancedList(list):
+class QueryList(list):
     """Create a list that mocks the behaviour of a query result"""
 
     def __init__(self):
-        super(EnhancedList, self).__init__()
+        super(QueryList, self).__init__()
 
     def first(self):
-        """Mock the first method """
+        """Mock the first method"""
         if len(self) == 0:
             return None
         return self[0]
@@ -134,7 +140,7 @@ class MockBundle:
         self.id = kwargs.get("id", 1)
         self.name = kwargs.get("name", "yellowhog")
         self.created_at = kwargs.get("created_at", datetime.datetime.now())
-        self.versions = kwargs.get("versions", [MockVersion(bundle=self)])
+        self.versions = kwargs.get("versions", [])
 
     def __repr__(self):
         return f"MockBundle:id={self.id}, name={self.name}, versions={self.versions}"
@@ -146,9 +152,9 @@ class MockHousekeeperAPI:
     def __init__(self, config=None):
         self._version_obj = None
         self._bundle_obj = None
-        self._files = EnhancedList()
-        self._tags = EnhancedList()
-        self._bundles = EnhancedList()
+        self._files = QueryList()
+        self._tags = QueryList()
+        self._bundles = QueryList()
         self._id_counter = 1
         self._file_added = False
         self._file_included = False
@@ -167,11 +173,34 @@ class MockHousekeeperAPI:
         self.root_path = config.get("housekeeper", {}).get("root", str(ROOT_PATH))
 
     # Mock specific functions
-    def fetch_file_from_version(self, version_obj, tags):
+    def get_file_from_version(self, version: Version, tags: Set[str]):
         if tags.intersection(self._missing_tags):
             return None
         return self._files[0]
 
+    def get_latest_file_from_version(self, version: Version, tags: Set[str]):
+        if tags.intersection(self._missing_tags):
+            return None
+        return self._files[-1]
+
+    def get_file_from_latest_version(self, bundle_name: str, tags: List[str]) -> Optional[File]:
+        """Find a file in the latest version of a bundle."""
+        version: Version = self.last_version(bundle=bundle_name)
+        if not version:
+            LOG.info(f"Bundle: {bundle_name} not found in Housekeeper")
+            raise HousekeeperBundleVersionMissingError
+        return self.files(version=version.id, tags=tags).first()
+
+    def get_files_from_latest_version(
+        self, bundle_name: str, tags: List[str]
+    ) -> Optional[List[File]]:
+        """Return files in the latest version of a bundle."""
+        version: Version = self.last_version(bundle=bundle_name)
+        if not version:
+            LOG.info(f"Bundle: {bundle_name} not found in Housekeeper")
+            raise HousekeeperBundleVersionMissingError
+        return self.files(version=version.id, tags=tags)
+
     def add_missing_tag(self, tag_name: str):
         """Add a missing tag"""
         self._missing_tags.add(tag_name)
@@ -209,7 +238,7 @@ class MockHousekeeperAPI:
 
     # Mocked functions from original API
     def add_bundle(self, bundle_data):
-        """ Build a new bundle version of files """
+        """Build a new bundle version of files"""
         bundle_obj = self.new_bundle(name=bundle_data["name"], created_at=bundle_data["created"])
 
         version_obj = self.new_version(
@@ -233,8 +262,7 @@ class MockHousekeeperAPI:
                 self._file_added = True
                 version_obj.files.append(new_file)
         version_obj.bundle_obj = bundle_obj
-        bundle_obj.versions = version_obj
-
+        bundle_obj.versions.append(version_obj)
         return bundle_obj, version_obj
 
     def _build_tags(self, tag_names: List[str]) -> dict:
@@ -242,22 +270,22 @@ class MockHousekeeperAPI:
         tags = {}
         for tag_name in tag_names:
             if self.tag_exists(tag_name):
-                tag_obj = self.tag(tag_name)
+                tag_obj = self.get_tag(tag_name)
             else:
                 tag_obj = self.new_tag(tag_name)
                 self._tags.append(tag_obj)
             tags[tag_name] = tag_obj
         return tags
 
-    def tag(self, name: str):
-        """ Fetch a tag """
+    def get_tag(self, name: str):
+        """Fetch a tag"""
         for tag_obj in self._tags:
             if tag_obj.name == name:
                 return tag_obj
         return None
 
     def bundle(self, name: str) -> MockBundle:
-        """ Fetch a bundle """
+        """Fetch a bundle"""
         if name:
             for bundle_obj in self.bundles():
                 if bundle_obj.name == name:
@@ -265,11 +293,11 @@ class MockHousekeeperAPI:
         return self._bundle_obj
 
     def bundles(self):
-        """ Fetch bundles """
+        """Fetch bundles"""
         return self._bundles
 
     def new_bundle(self, name: str, created_at: datetime.datetime = None):
-        """ Create a new file bundle """
+        """Create a new file bundle"""
         self.update_id_counter()
         bundle_obj = MockBundle(id=self._id_counter, name=name, created_at=created_at)
         self._bundle_obj = bundle_obj
@@ -277,9 +305,25 @@ class MockHousekeeperAPI:
         return bundle_obj
 
     def version(self, *args, **kwargs):
-        """ Fetch a version """
+        """Fetch a version"""
         return self._version_obj
 
+    def get_create_version(self, bundle_name: str):
+        """Returns the latest version of a bundle if it exists. If no creates a bundle and returns its version"""
+        last_version = self.last_version(bundle=bundle_name)
+        if not last_version:
+            LOG.info(f"Creating bundle for sample {bundle_name} in housekeeper")
+            bundle_result = self.add_bundle(
+                bundle_data={
+                    "name": bundle_name,
+                    "created": datetime.datetime.now(),
+                    "expires": None,
+                    "files": [],
+                }
+            )
+            last_version = bundle_result[1]
+        return last_version
+
     def files(self, *args, **kwargs):
         """
         Fetch files.
@@ -287,11 +331,11 @@ class MockHousekeeperAPI:
         """
         tags = set(kwargs.get("tags", []))
         if tags.intersection(self._missing_tags):
-            return EnhancedList()
+            return QueryList()
         return self._files
 
     def new_tag(self, name: str, category: str = None):
-        """ Create a new tag """
+        """Create a new tag"""
         self.update_id_counter()
         tag_obj = MockTag(id=self._id_counter, name=name, category=category)
         if not self.tag_exists(name):
@@ -300,14 +344,14 @@ class MockHousekeeperAPI:
         return tag_obj
 
     def add_tag(self, name: str, category: str = None):
-        """ Add a tag to the database """
+        """Add a tag to the database"""
         tag_obj = self.new_tag(name, category)
         if not self.tag_exists(name):
             self._tags.append(tag_obj)
         return tag_obj
 
     def new_version(self, created_at: datetime.datetime, expires_at: datetime.datetime = None):
-        """ Create a new bundle version """
+        """Create a new bundle version"""
         self.update_id_counter()
         created_at = created_at or datetime.datetime.now()
         expires_at = expires_at or datetime.datetime.now()
@@ -321,7 +365,7 @@ class MockHousekeeperAPI:
         created_at: datetime.datetime = None,
         expires_at: datetime.datetime = None,
     ):
-        """ Create a new bundle version """
+        """Create a new bundle version"""
         if not version_obj:
             version_obj = self.new_version(created_at, expires_at)
         self._version_obj = version_obj
@@ -334,7 +378,7 @@ class MockHousekeeperAPI:
         to_archive: bool = False,
         tags: list = [],
     ):
-        """ Create a new file """
+        """Create a new file"""
         self.update_id_counter()
         mocked_file = MockFile(
             id=self._id_counter,
@@ -349,11 +393,11 @@ class MockHousekeeperAPI:
         return mocked_file
 
     def add_commit(self, *args, **kwargs):
-        """ Wrap method in Housekeeper Store """
+        """Wrap method in Housekeeper Store"""
         return True
 
     def commit(self):
-        """ Wrap method in Housekeeper Store """
+        """Wrap method in Housekeeper Store"""
         return True
 
     def include(self, *args, **kwargs):
@@ -365,13 +409,27 @@ class MockHousekeeperAPI:
         self._file_included = True
 
     def last_version(self, *args, **kwargs):
-        """Gets the latest version of a bundle"""
+        """Gets the latest version of a bundle."""
         if self._last_version is False:
             return None
+        if len(args) > 0:
+            bundle = self.bundle(args[0])
+            if bundle:
+                return bundle.versions[-1]
         return self._version_obj
 
+    def get_latest_bundle_version(self, bundle_name: str):
+        """Get latest version of a bundle or log."""
+        last_version = self.last_version(bundle_name)
+        if not last_version:
+            LOG.warning(f"No bundle found for {bundle_name} in Housekeeper")
+            return None
+        LOG.debug(f"Found version obj for {bundle_name}: {repr(last_version)}")
+        return last_version
+
     def get_root_dir(self):
-        """Returns the root dir of Housekeeper"""
+        """Returns the root dir of Housekeeper."""
+
         return self.root_path
 
     def get_files(self, *args, **kwargs):
@@ -389,13 +447,13 @@ class MockHousekeeperAPI:
         if isinstance(tags, str):
             tags = [tags]
         for tag_name in tags:
-            if not self.tag(tag_name):
+            if not self.get_tag(tag_name):
                 self.add_tag(tag_name)
 
         new_file = self.new_file(
             path=str(Path(path).absolute()),
             to_archive=to_archive,
-            tags=[self.tag(tag_name) for tag_name in tags],
+            tags=[self.get_tag(tag_name) for tag_name in tags],
         )
         if not version_obj:
             version_obj = self.new_version(created_at=datetime.datetime.now())
@@ -403,8 +461,95 @@ class MockHousekeeperAPI:
         if not self.file_exists(path):
             self._files.append(new_file)
         self._file_added = True
+        version_obj.files.append(new_file)
         return new_file
 
+    def check_bundle_files(
+        self, bundle_name: str, file_paths: List[Path], last_version, tags: Optional[list] = None
+    ) -> List[Path]:
+        """Checks if any of the files in the provided list are already added to the provided bundle. Returns a list of files that have not been added"""
+        for file in self.get_files(bundle=bundle_name, tags=tags, version=last_version.id):
+            if Path(file.path) in file_paths:
+                file_paths.remove(Path(file.path))
+                LOG.info(
+                    "Path %s is already linked to bundle %s in housekeeper"
+                    % (file.path, bundle_name)
+                )
+        return file_paths
+
+    def create_new_bundle_and_version(self, name: str) -> Bundle:
+        """Create new bundle with version"""
+        new_bundle = self.new_bundle(name=name)
+        self.add_commit(new_bundle)
+        new_version = self.new_version(created_at=new_bundle.created_at)
+        new_bundle.versions.append(new_version)
+        self.commit()
+        LOG.info("New bundle created with name %s", new_bundle.name)
+        return new_bundle
+
+    def add_and_include_file_to_latest_version(
+        self, bundle_name: str, file: Path, tags: list
+    ) -> None:
+        """Adds and includes a file in the latest version of a bundle."""
+        version: Version = self.last_version(bundle_name)
+        if not version:
+            LOG.info(f"Bundle: {bundle_name} not found in housekeeper")
+            raise HousekeeperBundleVersionMissingError
+        hk_file: File = self.add_file(version_obj=version, tags=tags, path=str(file.absolute()))
+        self.include_file(version_obj=version, file_obj=hk_file)
+        self.commit()
+
+    def include_files_to_latest_version(self, bundle_name: str) -> None:
+        """Include all files in the latest version on a bundle."""
+        bundle_version: Version = self.get_latest_bundle_version(bundle_name=bundle_name)
+        self.include(version_obj=bundle_version)
+        self.commit()
+
+    def is_fastq_or_spring_in_all_bundles(self, bundle_names: List[str]) -> bool:
+        """Return whether or not all FASTQ/SPRING files are included for the given bundles."""
+        sequencing_files_in_hk: Dict[str, bool] = {}
+        for bundle_name in bundle_names:
+            sequencing_files_in_hk[bundle_name] = False
+            for tag in [SequencingFileTag.FASTQ, SequencingFileTag.SPRING_METADATA]:
+                sample_file_in_hk: List[bool] = []
+                hk_files: Optional[List[File]] = self.get_files_from_latest_version(
+                    bundle_name=bundle_name, tags=[tag]
+                )
+                sample_file_in_hk += [True for hk_file in hk_files if hk_file.is_included]
+                if sample_file_in_hk:
+                    break
+            sequencing_files_in_hk[bundle_name] = (
+                all(sample_file_in_hk) if sample_file_in_hk else False
+            )
+        return all(sequencing_files_in_hk.values())
+
+    def delete_file(self, file_id: int) -> Optional[File]:
+        """Mock deleting a file both from database and disk (if included)."""
+        file_obj = self._get_mock_file(file_id)
+        if not file_obj:
+            LOG.info(f"Could not find file {file_id}")
+            return
+
+        if file_obj.is_included and Path(file_obj.full_path).exists():
+            LOG.info(f"Deleting file {file_obj.full_path} from disc")
+            Path(file_obj.full_path).unlink()
+
+        LOG.info(f"Deleting file {file_id} from mock housekeeper")
+        self._files.remove(file_obj)
+
+        return file_obj
+
+    def _get_mock_file(self, file_id: int) -> Optional[File]:
+        for file_obj in self._files:
+            if file_obj.id == file_id:
+                return file_obj
+        return None
+
+    @staticmethod
+    def get_tag_names_from_file(file) -> [str]:
+        """Fetch a tag"""
+        return HousekeeperAPI.get_tag_names_from_file(file=file)
+
     @staticmethod
     def checksum(path):
         """Calculate the checksum"""
@@ -418,7 +563,7 @@ class MockHousekeeperAPI:
 
     @contextmanager
     def session_no_autoflush(self):
-        """ Wrap property in Housekeeper Store """
+        """Wrap property in Housekeeper Store"""
         yield True
 
     def __repr__(self):
