@@ -1,6 +1,7 @@
-from cg.apps.tb.models import TrailblazerAnalysis
 from typing import Optional
 
+from cg.apps.tb.models import TrailblazerAnalysis
+
 
 class MockTB:
     def __init__(self):
@@ -37,3 +38,12 @@ class MockTB:
         self.get_latest_analysis_response[analysis_dict["family"]] = TrailblazerAnalysis.parse_obj(
             analysis_dict
         )
+
+    def is_latest_analysis_completed(self, case_id: str):
+        return True
+
+    def is_latest_analysis_qc(self, case_id: str):
+        return True
+
+    def set_analysis_status(self, case_id: str, status: str):
+        return
