@@ -2,9 +2,10 @@
 import os
 
 import pytest
+
 from cg.server.app import create_app
 
-os.environ["CG_SQL_DATABASE_URI"] = "dummy_value"
+os.environ["CG_SQL_DATABASE_URI"] = "sqlite:///:memory:"
 os.environ["LIMS_HOST"] = "dummy_value"
 os.environ["LIMS_USERNAME"] = "dummy_value"
 os.environ["LIMS_PASSWORD"] = "dummy_value"
