@@ -1,11 +1,6 @@
 """
 Tests for command module
 """
-from subprocess import CalledProcessError
-
-import pytest
-
-from cg.utils import Process
 
 
 def test_add_microbial_sample(base_store, helpers):
@@ -24,3 +19,17 @@ def test_add_microbial_sample(base_store, helpers):
     assert sample.customer
     # THEN there should be an application_version
     assert sample.application_version
+
+
+def test_add_invoice(base_store, helpers):
+    # GIVEN a base_store
+    sample = helpers.add_sample(base_store)
+    # WHEN using the helper to add an invoice with a sample
+    invoice_sample = helpers.ensure_invoice(
+        base_store,
+        invoice_id=1,
+        samples=[sample],
+    )
+
+    # THEN there should be an invoice
+    assert invoice_sample
