@@ -1,6 +1,7 @@
 """Fixtures for utils"""
 
 import pytest
+
 from cg.utils import Process
 
 
@@ -14,16 +15,6 @@ def ls_process():
     return process
 
 
-@pytest.fixture(scope="function")
-def echo_process():
-    """
-    echo process
-    """
-    binary = "echo"
-    process = Process(binary=binary)
-    return process
-
-
 @pytest.fixture(scope="function")
 def stderr_output():
     """
